local ns = G13BarManager

--This frame is simply to handle the events so we can get the SavedVariables
local frame = CreateFrame("Frame")
frame:RegisterEvent("ADDON_LOADED")
frame:SetScript("OnEvent", function(self)
	--Set the defaults if there aren't SavedVaiables values
	G13BarManager = G13BarManager or {
		HKVis = true,
		MenuVis = true
	}
	end)
	
--This reparents a list of objects (usually buttons in our case).
function MoveElements(ElementList, FrameName)
	for _, v in pairs(ElementList) do
		v:SetParent(FrameName)
	end
end

--Simply hides a list of objects (again, usually buttons for us).
function HideElements(ElementList)
	for _, v in pairs(ElementList) do
		v:Hide()
	end
end

function HideHotKeys()
	for i = 1, 12 do
		_G["MultiBarBottomLeftButton"..i.."HotKey"]:SetAlpha(0)
		_G["ActionButton"..i.."HotKey"]:SetAlpha(0)
	end
end

function ShowHotKeys()
	for i = 1, 12 do
		_G["MultiBarBottomLeftButton"..i.."HotKey"]:SetAlpha(1)
		_G["ActionButton"..i.."HotKey"]:SetAlpha(1)
	end
end

--This code is for the black boxes when the bars are unlocked and movable.
function SetBackground(frame)
	frame:SetBackdrop({
	 bgFile="Interface\\ChatFrame\\ChatFrameBackground",
	 edgeFile="Interface\\ChatFrame\\ChatFrameBackground",
	 tile=true,
	 tileSize=5,
	 edgeSize= 1,
	})
	frame:SetBackdropColor(0,0,0,1)
	frame:SetBackdropBorderColor(0,0,0,1)
end

function ClearBackground(frame)
	frame:SetBackdrop(nil)
end

--Sets a given frame to be movable
function MakeDraggable(frame)
	frame:SetMovable(true)
	frame:EnableMouse(true)
	frame:RegisterForDrag("LeftButton")
	frame:SetScript("OnDragStart", frame.StartMoving)
	frame:SetScript("OnDragStop", frame.StopMovingOrSizing)
end

--Sets a frame to be immovable
function MakeStatic(frame)
	frame:SetMovable(false)
	frame:EnableMouse(false)
end

function UnlockFrame(frame)
	MakeDraggable(frame)
	SetBackground(frame)
end

function LockFrame(frame)
	MakeStatic(frame)
	ClearBackground(frame)
end

--Hides all the buttons when we unlock the bars.
function HideAllButtons()
	for _, v in pairs(MenuButtons) do
		v:Hide()
	end
	for i = 1, 12 do
		_G["ActionButton"..i]:Hide()
		_G["MultiBarBottomLeftButton"..i]:Hide()
		_G["MultiBarBottomRightButton"..i]:Hide()
	end
	for i = 1, 10 do
		_G["PetActionButton"..i]:Hide()
	end
	for i = 1, 6 do
		_G["StanceButton"..i]:Hide()
	end
	for i = 0, 3 do
		_G["CharacterBag"..i.."Slot"]:Hide()
	end
	MainMenuBarBackpackButton:Hide()
end

--Shows the buttons again when the bars are locked.
function ShowAllButtons()
	for _, v in pairs(MenuButtons) do
		v:Show()
	end
	for i = 1, 12 do
		_G["ActionButton"..i]:Show()
		_G["MultiBarBottomLeftButton"..i]:Show()
		_G["MultiBarBottomRightButton"..i]:Show()
	end
	for i = 1, 10 do
		_G["PetActionButton"..i]:Show()
	end
	for i = 1, 6 do
		_G["StanceButton"..i]:Show()
	end
	for i = 0, 3 do
		_G["CharacterBag"..i.."Slot"]:Show()
	end
	MainMenuBarBackpackButton:Show()
end